# Generated by roxygen2: do not edit by hand


  importFrom(shiny, reactiveVal)
  export(reactiveVal)
  importFrom(shiny, reactive)
  export(reactive)
  importFrom(shiny, observe)
  export(observe)
  importFrom(shiny, observeEvent)
  export(observeEvent)
  importFrom(shiny, isolate)
  export(isolate)
  importFrom(shiny, tags)
  export(tags)
  importFrom(shiny, tagList)
  export(tagList)
S3method("$",reactiveStore)
S3method("[[",reactiveStore)
S3method("[[<-",reactiveStore)
S3method(as.list,reactiveStore)
S3method(as_protocol,irid_dom_opts)
S3method(as_protocol,irid_echo_gate)
S3method(as_protocol,irid_wire_timing)
S3method(base::merge,irid_wire)
S3method(length,reactiveStore)
S3method(names,reactiveStore)
S3method(print,reactiveProxy)
S3method(print,reactiveStore)
S3method(str,reactiveStore)
S3method(vctrs::vec_proxy,reactiveStore)
export(Case)
export(DTOutput)
export(Default)
export(Each)
export(IridWidget)
export(Match)
export(Output)
export(PlotOutput)
export(PlotlyOutput)
export(TableOutput)
export(When)
export(iridApp)
export(iridExample)
export(iridOutput)
export(reactiveProxy)
export(reactiveStore)
export(renderIrid)
export(wire)
export(wire_debounce)
export(wire_dom_opts)
export(wire_immediate)
export(wire_throttle)
importFrom(rlang,"%||%")
importFrom(rlang,check_bool)
importFrom(rlang,check_number_decimal)
importFrom(rlang,check_string)
importFrom(rlang,is_function)
